@@ -24,6 +24,7 @@ void Database::initialize() {
     database.open();
     database.exec("DROP TABLE IF EXISTS savedDownloads");
     database.exec("CREATE TABLE IF NOT EXISTS downloads (videoId TEXT UNIQUE, title TEXT, thumbnail TEXT, convertToAudio INTEGER, youtube INTEGER, dailymotion INTEGER, youporn INTEGER)");
+    database.exec("ALTER TABLE downloads ADD COLUMN xvideos INTEGER");
     database.close();
 }
 
@@ -33,7 +34,7 @@ bool Database::storeDownload(const QVariantMap &video) {
     }
     bool querySuccessful;
     QSqlQuery query;
-    query.prepare("INSERT OR REPLACE INTO downloads VALUES (?, ?, ?, ?, ?, ?, ?)");
+    query.prepare("INSERT OR REPLACE INTO downloads VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
     query.addBindValue(video.value("videoId").toString());
     query.addBindValue(video.value("title").toString());
     query.addBindValue(video.value("thumbnail").toString());
@@ -41,6 +42,7 @@ bool Database::storeDownload(const QVariantMap &video) {
     query.addBindValue(video.value("youtube").toInt());
     query.addBindValue(video.value("dailymotion").toInt());
     query.addBindValue(video.value("youporn").toInt());
+    query.addBindValue(video.value("xvideos").toInt());
     querySuccessful = query.exec();
     database.close();
     return querySuccessful;
@@ -67,7 +69,7 @@ QVariantList Database::getStoredDownloads() {
     QSqlRecord record;
     QVariantMap downloadItem;
     QVariantList downloads;
-    query.exec("SELECT videoId, title, thumbnail, convertToAudio, youtube, dailymotion, youporn FROM downloads");
+    query.exec("SELECT videoId, title, thumbnail, convertToAudio, youtube, dailymotion, youporn, xvideos FROM downloads");
     record = query.record();
     if (record.count() > 0) {
         while (query.next()) {
@@ -78,6 +80,7 @@ QVariantList Database::getStoredDownloads() {
             downloadItem.insert("youtube", query.value(4));
             downloadItem.insert("dailymotion", query.value(5));
             downloadItem.insert("youporn", query.value(6));
+            downloadItem.insert("xvideos", query.value(7));
             downloadItem.insert("status", QString("paused"));
             downloads.append(downloadItem);
         }
