@@ -46,6 +46,7 @@ int main(int argc, char *argv[])
     QObject::connect(&daily, SIGNAL(gotVideoUrl(QString)), &ut, SLOT(playVideo(QString)));
     QObject::connect(&daily, SIGNAL(signedIn(QString,QString,QString,int)), &settings, SLOT(setDailymotionAccount(QString,QString,QString,int)));
     QObject::connect(&daily, SIGNAL(signedOut()), &settings, SLOT(clearDailymotionAccount()));
+    QObject::connect(&xt, SIGNAL(gotVideoUrl(QString)), &ut, SLOT(playVideo(QString)));
 
     qmlRegisterType<QDeclarativeFolderListModel>("Models",1,0,"FolderListModel");
 
@@ -66,6 +67,7 @@ int main(int argc, char *argv[])
         app.installTranslator(&translator);
     }
 
+    viewer.setWindowTitle(QString("cuteTube-QML"));
     viewer.engine()->addImportPath(QString("/opt/qtm12/imports"));
     viewer.engine()->addPluginPath(QString("/opt/qtm12/plugins"));
     viewer.setMainQmlFile(QLatin1String("qml/qmltube/main.qml"));
