@@ -19,16 +19,16 @@
 Utils::Utils(QObject *parent) :
     QObject(parent), viewer(0) {
 
-    systemInfo = new QSystemInfo(this);
-    deviceInfo = new QSystemDeviceInfo(this);
-    connect(deviceInfo, SIGNAL(batteryLevelChanged(int)), this, SIGNAL(batteryLevelChanged()));
+//    systemInfo = new QSystemInfo(this);
+//    deviceInfo = new QSystemDeviceInfo(this);
+//    connect(deviceInfo, SIGNAL(batteryLevelChanged(int)), this, SIGNAL(batteryLevelChanged()));
     QTimer *timer = new QTimer(this);
     timer->setSingleShot(false);
     timer->setInterval(30000);
     connect(timer, SIGNAL(timeout()), this, SIGNAL(currentTimeChanged()));
     timer->start();
     emit currentTimeChanged();
-    emit batteryLevelChanged();
+//    emit batteryLevelChanged();
 }
 
 void Utils::setView(QmlApplicationViewer *view) {
@@ -52,13 +52,13 @@ QString Utils::getCurrentTime() const {
     return QTime::currentTime().toString("h:mm ap");
 }
 
-int Utils::getBatteryLevel() const {
-    return deviceInfo->batteryLevel();
-}
+//int Utils::getBatteryLevel() const {
+//    return deviceInfo->batteryLevel();
+//}
 
-QString Utils::getInstalledQtVersion() const {
-    return systemInfo->version(QSystemInfo::QtCore);
-}
+//QString Utils::getInstalledQtVersion() const {
+//    return systemInfo->version(QSystemInfo::QtCore);
+//}
 
 void Utils::doNotDisturb(bool preventDisturb) {
 #ifdef Q_WS_MAEMO_5
@@ -104,10 +104,6 @@ bool Utils::widgetInstalled() const {
     return QFile::exists(QString("/usr/lib/hildon-desktop/qmltube-widget"));
 }
 
-bool Utils::xTubeInstalled() const {
-    return QFile::exists(QString("/opt/qmltube/qml/qmltube/scripts/xtube.js"));
-}
-
 QVariantList Utils::getInstalledMediaPlayers() const {
     QVariantList playerList;
     QVariantMap player;
