@@ -4,12 +4,12 @@
 #include <QObject>
 #include <QProcess>
 #include <QVariantList>
-#include <QSystemInfo>
-#include <QSystemDeviceInfo>
+//#include <QSystemInfo>
+//#include <QSystemDeviceInfo>
 
 class QWidget;
 
-using namespace QtMobility;
+//using namespace QtMobility;
 
 #include "qmlapplicationviewer.h"
 
@@ -19,22 +19,21 @@ class Utils : public QObject {
     Q_PROPERTY(QString currentTime
                READ getCurrentTime
                NOTIFY currentTimeChanged)
-    Q_PROPERTY(int batteryLevel
-               READ getBatteryLevel
-               NOTIFY batteryLevelChanged)
+//    Q_PROPERTY(int batteryLevel
+//               READ getBatteryLevel
+//               NOTIFY batteryLevelChanged)
 
 public:
     explicit Utils(QObject *parent = 0);
 
     void setView(QmlApplicationViewer* view);
     QString getCurrentTime() const;
-    int getBatteryLevel() const;
+//    int getBatteryLevel() const;
 
 public slots:
 
     QVariantList getInstalledMediaPlayers() const;
     bool widgetInstalled() const;
-    bool xTubeInstalled() const;
     void setMediaPlayer(const QString &player);
     void doNotDisturb(bool preventDisturb);
     void toggleState();
@@ -43,18 +42,18 @@ public slots:
     bool pathExists(const QString &path);
     void copyToClipboard(const QString &url);
     QString getDocsDirectory() const;
-    QString getInstalledQtVersion() const;
+//    QString getInstalledQtVersion() const;
 
 private:
     QmlApplicationViewer *viewer;
     QString mediaPlayer;
-    QSystemInfo *systemInfo;
-    QSystemDeviceInfo *deviceInfo;
+//    QSystemInfo *systemInfo;
+//    QSystemDeviceInfo *deviceInfo;
 
 signals:
     void alert(const QString &message);
     void currentTimeChanged();
-    void batteryLevelChanged();
+//    void batteryLevelChanged();
 };
 
 #endif // UTILS_H
